<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="FunctionForXsl.xsl"/>
	<xsl:output method="xml"/>
	<xsl:template name="SumStr">
		<xsl:param name="SumValue"/>
		<xsl:variable name="SumVal1" select="format-number(substring-before(format-number($SumValue,'#.000'),'.'),'#')"/>
		<xsl:variable name="SumVal2">
			<xsl:call-template name='RecurseSumWords'>
				<xsl:with-param name='Value' select='$SumVal1'/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="SumVal3" select="format-number(format-number($SumValue,'#.000')-$SumVal1,'0.000')"/>
		<xsl:choose>
			<xsl:when test="$SumVal3!=0">
				<xsl:value-of select="concat($SumVal2,' ', substring-after(string($SumVal3),'.'))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$SumVal2"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="OrgPackage">
		<xsl:param name="Pref"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="NodeAdd"/>
		<xsl:for-each select="$NodeName">
			<xsl:element name="{concat($Pref,'Name')}"><xsl:value-of select="OrganizationName"/></xsl:element>
			<xsl:element name="{concat($Pref,'ShortName')}"><xsl:value-of select="OrganizationName"/></xsl:element>
			<xsl:choose>
				<xsl:when test="count(RFOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'OGRN')}"><xsl:value-of select="RFOrganizationFeatures/OGRN"/></xsl:element>
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RFOrganizationFeatures/INN"/></xsl:element>
					<xsl:element name="{concat($Pref,'KPP')}"><xsl:value-of select="RFOrganizationFeatures/KPP"/></xsl:element>
				</xsl:when>
				<xsl:when test="count(RBOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RBOrganizationFeatures/INN"/></xsl:element>
				</xsl:when>
				<xsl:when test="count(RKOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'OGRN')}"><xsl:value-of select="RKOrganizationFeatures/BIN"/></xsl:element>
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RKOrganizationFeatures/INN"/></xsl:element>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
		<xsl:call-template name="AddressOrg">
			<xsl:with-param name="Pref" select="$Pref"/>
			<xsl:with-param name="NodeAdd" select="$NodeAdd"/>
		</xsl:call-template> 
	</xsl:template>	
	
   <xsl:template name="AddressOrg">
   		<xsl:param name="Pref"/>
		<xsl:param name="NodeAdd"/>
   		<xsl:for-each select="$NodeAdd">
			<xsl:element name="{concat($Pref,'PostalCode')}"><xsl:value-of select="PostalCode"/></xsl:element>
			<xsl:element name="{concat($Pref,'CountryCode')}"><xsl:value-of select="CountryCode"/></xsl:element>
			<xsl:element name="{concat($Pref,'CountryName')}"><xsl:value-of select="CounryName"/></xsl:element>
			<xsl:element name="{concat($Pref,'Region')}"><xsl:value-of select="Region"/></xsl:element>
			<xsl:element name="{concat($Pref,'City')}"><xsl:value-of select="City"/></xsl:element>
			<xsl:element name="{concat($Pref,'StreetHouse')}"><xsl:value-of select="StreetHouse"/></xsl:element>
		</xsl:for-each>		
	</xsl:template>

	<xsl:key use="concat(./PrDocumentNumber,./PrDocumentDate)" name="PackListDoc" match="//CUPresentedDocuments[PresentedDocumentModeCode='00000']"/>
	<xsl:template match="CUPresentedDocuments[PresentedDocumentModeCode='00000']">
		<xsl:param name="Doc"/>
		<xsl:param name="NumCmr"/>
		<xsl:param name="DatCmr"/>
		<xsl:param name="PosSh"/>
		<xsl:variable name="NumDoc" select="PrDocumentNumber"/>
		<xsl:variable name="DatDoc" select="PrDocumentDate"/>
		<xsl:choose>
			<xsl:when test="$Doc=1">
				<CMRENCLOSEDDOCUMENT_ITEM>
					<DOC_ID>0</DOC_ID>
					<PrDocumentName><xsl:value-of select="PrDocumentName"/></PrDocumentName>
					<PrDocumentNumber><xsl:value-of select="$NumDoc"/></PrDocumentNumber>
					<xsl:if test="string-length($DatDoc)>0">
						<PrDocumentDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></PrDocumentDate>
					</xsl:if>
					<ModeCode>04131</ModeCode>
				</CMRENCLOSEDDOCUMENT_ITEM>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="PackL">
					<xsl:with-param name="NumCmr" select="$NumCmr"/>
					<xsl:with-param name="DatCmr" select="$DatCmr"/>
					<xsl:with-param name="NumDoc" select="$NumDoc"/>
					<xsl:with-param name="DatDoc" select="$DatDoc"/>
					<xsl:with-param name="PosSh" select="$PosSh"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template name="PackL">
		<xsl:param name="NumCmr"/>
		<xsl:param name="DatCmr"/>
		<xsl:param name="NumDoc"/>
		<xsl:param name="DatDoc"/>
		<xsl:param name="PosSh"/>
		<xsl:for-each select="//TIRShipment[position()=$PosSh]">	
		<PACKINGLIST ctmtd:CfgName="PackingList.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
				<PACKINGLIST_ITEM>
					<DOC_ID>0</DOC_ID>
					<pi>2</pi>
					<DocName>Отгрузочный (упаковочный) лист</DocName>
					<xsl:choose>
						<xsl:when test="string-length($NumDoc)>0 and string-length($DatDoc)>0">
							<RegNum><xsl:value-of select="$NumDoc"/></RegNum>
							<xsl:if test="string-length($DatDoc)>0">
								<RegDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></RegDate>
							</xsl:if>	
						</xsl:when>
						<xsl:otherwise>
							<RegNum><xsl:value-of select="$PosSh"/></RegNum>
							<xsl:if test="string-length(//TIRCarnet/DocumentDate)>0">
								<RegDate><xsl:value-of select="concat(//TIRCarnet/DocumentDate,'T00:00:00.0Z')"/></RegDate>
							</xsl:if>	
						</xsl:otherwise>
					</xsl:choose>
					<GrossWeightQuantity><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/GrossWeightQuantity),'#.000')"/></GrossWeightQuantity>
					<NetWeightQuantity><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/NetWeightQuantity),'#.000')"/></NetWeightQuantity>
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Consignor_'"/>
						<xsl:with-param name="NodeName" select="Consignor"/>
						<xsl:with-param name="NodeAdd" select="Consignor/Address"/>
					</xsl:call-template> 
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Consignee_'"/>
						<xsl:with-param name="NodeName" select="Consignee"/>
						<xsl:with-param name="NodeAdd" select="Consignee/Address"/>
					</xsl:call-template> 
					
					<DeliveryPlace><xsl:value-of select="Destination/DestinationPlaceName"/></DeliveryPlace>
					<xsl:if test="string-length(CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentNumber)>0">
						<ContractName><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentName"/></ContractName>
						<ContractNum><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentNumber"/></ContractNum>
						<ContractDate><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentDate"/></ContractDate>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="string-length(CUPresentedDocuments[PresentedDocumentModeCode='04021']/PrDocumentNumber)>0">
							<InvoiceName><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='04021']/PrDocumentName"/></InvoiceName>
							<InvoiceNum><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='04021']/PrDocumentNumber"/></InvoiceNum>
							<InvoiceDate><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='04021']/PrDocumentDate"/></InvoiceDate>
						</xsl:when>
						<xsl:otherwise>
							<InvoiceName>Invoice</InvoiceName>
							<InvoiceNum><xsl:value-of select="$PosSh"/></InvoiceNum>
							<xsl:if test="string-length(//TIRCarnet/DocumentDate)>0">
								<InvoiceDate><xsl:value-of select="//TIRCarnet/DocumentDate"/></InvoiceDate>
							</xsl:if>	
						</xsl:otherwise>
					</xsl:choose> 
					<PACKINGLISTGoods>
						<xsl:for-each select="TIRGoods">
							<PACKINGLISTGOODS_ITEM>
								<DOC_ID>0</DOC_ID>
								<PlacesQuantity><xsl:value-of select="PlacesInfo/PakingQuantity"/></PlacesQuantity>
								<PlacesDescription><xsl:value-of select="PlacesInfo/PackingDescription"/></PlacesDescription>
								<PlacesCode><xsl:value-of select="PlacesInfo/PackingCode"/></PlacesCode>									
								<GoodsDescription><xsl:value-of select="GoodsDescription"/></GoodsDescription>
								<GoodsQuantity><xsl:value-of select="SupplementaryGoodsQuantity"/></GoodsQuantity>
								<xsl:if test="string-length(SupplementaryMeasureUnitCode)>0">
									<xsl:variable name="UnitC" select="SupplementaryMeasureUnitCode"/>
									<MeasureUnitQualifierName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//UNIT_ITEM[CODE=$UnitC]/ABBR"/></MeasureUnitQualifierName>
									<MeasureUnitQualifierCode><xsl:value-of select="SupplementaryMeasureUnitCode"/></MeasureUnitQualifierCode>
								</xsl:if>								
								<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
								<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
								<PACKINGLISTGoodsPlaces>
									<xsl:for-each select="PlacesInfo">
										<PACKINGLISTGOODSPLACES_ITEM>
											<DOC_ID>0</DOC_ID>
											<PlacesQuantity><xsl:value-of select="PakingQuantity"/></PlacesQuantity>
											<PlacesDescription><xsl:value-of select="PackingDescription"/></PlacesDescription>
											<PlacesCode><xsl:value-of select="PackingCode"/></PlacesCode>		
										</PACKINGLISTGOODSPLACES_ITEM>
									</xsl:for-each>
								</PACKINGLISTGoodsPlaces>
								<PACKINGLISTGoodsPackingInfo>
									<xsl:for-each select="PackingInfo">
										<PACKINGLISTGOODSPACKINGINFO_ITEM>
											<DOC_ID>0</DOC_ID>
											<PackingCode><xsl:value-of select="PackingCode"/></PackingCode>
											<xsl:variable name="PackC" select="PackingCode"/>
											<PackingDescription><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PackC]/Name"/></PackingDescription>
											<!--<PackingMark><xsl:value-of select="PackingMark"/></PackingMark>-->
											<PackingQuantity><xsl:value-of select="PakingQuantity"/></PackingQuantity>
										</PACKINGLISTGOODSPACKINGINFO_ITEM>
									</xsl:for-each>	
								</PACKINGLISTGoodsPackingInfo>
							</PACKINGLISTGOODS_ITEM>
						</xsl:for-each>
					</PACKINGLISTGoods>
					<PACKINGLISTTotalPlaces>
						<xsl:for-each select="//TIRShipment[position()=$PosSh]/TIRGoods[not(PlacesInfo/PackingCode =preceding::*/PlacesInfo/PackingCode)]/PlacesInfo/PackingCode">
							<xsl:sort select="."/>
							<xsl:variable name="PackC" select="."/>						
							<PACKINGLISTTOTALPLACES_ITEM>
								<DOC_ID>0</DOC_ID>
								<PlacesQuantity><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods[PlacesInfo/PackingCode=$PackC]/PlacesInfo/PakingQuantity),'#')"/></PlacesQuantity>
								<PlacesDescription><xsl:value-of select="$PackC"/></PlacesDescription>
								<PackingCode><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PackC]/Name"/></PackingCode>
							</PACKINGLISTTOTALPLACES_ITEM>
						</xsl:for-each>	
					</PACKINGLISTTotalPlaces>
				</PACKINGLIST_ITEM>
			</PACKINGLIST>
		</xsl:for-each>
	</xsl:template>	

	<xsl:key use="concat(./PrDocumentNumber,./PrDocumentDate)" name="InvoiceDoc" match="//CUPresentedDocuments[PresentedDocumentModeCode='04021']"/>
	<xsl:template match="CUPresentedDocuments[PresentedDocumentModeCode='04021']">
		<xsl:param name="Doc"/>
		<xsl:param name="NumCmr"/>
		<xsl:param name="DatCmr"/>
		<xsl:param name="PosSh"/>
		<xsl:variable name="NumDoc" select="PrDocumentNumber"/>
		<xsl:variable name="DatDoc" select="PrDocumentDate"/>
		
		<xsl:choose>
			<xsl:when test="$Doc=1">
				<CMRENCLOSEDDOCUMENT_ITEM>
					<DOC_ID>0</DOC_ID>
					<PrDocumentName><xsl:value-of select="PrDocumentName"/></PrDocumentName>
					<PrDocumentNumber><xsl:value-of select="$NumDoc"/></PrDocumentNumber>
					<xsl:if test="string-length($DatDoc)>0">
						<PrDocumentDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></PrDocumentDate>
					</xsl:if>	
					<ModeCode>04021</ModeCode>
				</CMRENCLOSEDDOCUMENT_ITEM>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Invoice">
					<xsl:with-param name="NumCmr" select="$NumCmr"/>
					<xsl:with-param name="DatCmr" select="$DatCmr"/>
					<xsl:with-param name="NumDoc" select="$NumDoc"/>
					<xsl:with-param name="DatDoc" select="$DatDoc"/>
					<xsl:with-param name="PosSh" select="$PosSh"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Invoice">
		<xsl:param name="NumCmr"/>
		<xsl:param name="DatCmr"/>
		<xsl:param name="NumDoc"/>
		<xsl:param name="DatDoc"/>
		<xsl:param name="PosSh"/>
		<xsl:for-each select="//TIRShipment[position()=$PosSh]">
			<INVOICE ctmtd:CfgName="invoice.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
				<INVOICE_ITEM>
					<DOC_ID>0</DOC_ID>
					<pi>2</pi>
					<xsl:variable name="Val" select="TIRGoods[1]/InvoicedCostCurrencyCode"/> 
					<xsl:if test="string-length($Val)>0">
						<CurrencyCode><xsl:value-of select="$Val"/></CurrencyCode>
					</xsl:if>
					<CurrencyNumber><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$Val]/Code"/></CurrencyNumber>
					<CurrencyName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$Val]/Name"/></CurrencyName>
					<GrossWeightQuantity><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/GrossWeightQuantity),'#.000')"/></GrossWeightQuantity>
					<NetWeightQuantity><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/NetWeightQuantity),'#.000')"/></NetWeightQuantity>
					<GCost><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/InvoicedCost),'#.00')"/></GCost>
					<OtherChargesName>Сумма прочих расходов</OtherChargesName>
					<TotalCost><xsl:value-of select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/InvoicedCost),'#.00')"/></TotalCost>
					<xsl:if test="string-length(sum(//TIRShipment[position()=$PosSh]/TIRGoods/InvoicedCost))>0">
						<TotalSign>						
							<xsl:call-template name='SumStr'>
								<xsl:with-param name='SumValue' select="format-number(sum(//TIRShipment[position()=$PosSh]/TIRGoods/InvoicedCost),'#.00')"/>
							</xsl:call-template>
							<xsl:if test="string-length($Val)>0">
								<xsl:value-of select="concat(' ',$Val)"/>
							</xsl:if>	
						</TotalSign>
					</xsl:if>
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Consignor_'"/>
						<xsl:with-param name="NodeName" select="TIRConsignor"/>
						<xsl:with-param name="NodeAdd" select="TIRConsignor/Address"/>
					</xsl:call-template> 
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Consignee_'"/>
						<xsl:with-param name="NodeName" select="TIRConsignee"/>
						<xsl:with-param name="NodeAdd" select="TIRConsignee/Address"/>
					</xsl:call-template>
					<INVOICEGoods>
						<xsl:for-each select="TIRGoods">
							<INVOICEGOODS_ITEM>
								<DOC_ID>0</DOC_ID>
								<GoodsCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsCode>
								<GoodsDescription>
									<xsl:for-each select="GoodsDescription">
										<xsl:value-of select="."/>
									</xsl:for-each>
								</GoodsDescription>
								<GoodsQuantity><xsl:value-of select="SupplementaryGoodsQuantity"/></GoodsQuantity>
								<xsl:if test="string-length(SupplementaryMeasureUnitCode)>0">
									<xsl:variable name="UnitC" select="SupplementaryMeasureUnitCode"/>
									<MeasureUnitQualifierName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//UNIT_ITEM[CODE=$UnitC]/ABBR"/></MeasureUnitQualifierName>
									<MeasureUnitQualifierCode><xsl:value-of select="SupplementaryMeasureUnitCode"/></MeasureUnitQualifierCode>
								</xsl:if>
								<PlacesQuantity><xsl:value-of select="PlacesInfo/PakingQuantity"/></PlacesQuantity>
								<xsl:variable name="PackC" select="PlacesInfo/PackingCode"/>
								<xsl:if 	test="string-length($PackC)">
									<PlacesDescription><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PackC]/Name"/></PlacesDescription>
									<PlacesCode><xsl:value-of select="$PackC"/></PlacesCode>
								</xsl:if> 
								<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
								<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
								<TotalCost><xsl:value-of select="InvoicedCost"/></TotalCost>
								<xsl:variable name="OrgC" select="OriginCountryCode"/>
								<OriginCountryCode><xsl:value-of select="$OrgC"/></OriginCountryCode>
								<OriginCountryNumber><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$OrgC]/Code"/></OriginCountryNumber>
								<OriginCountry><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$OrgC]/Name"/></OriginCountry>
							</INVOICEGOODS_ITEM>
						</xsl:for-each>	
					</INVOICEGoods>
					<Carriage>
						<xsl:for-each select="//CUTransport/TransportMeans">
							<CARRIAGE_ITEM>
								<DOC_ID>0</DOC_ID>
								<CarriageId><xsl:value-of select="TransportIdentifier"/></CarriageId>
							</CARRIAGE_ITEM>	
						</xsl:for-each>
					</Carriage>
					<xsl:if test="count(ContainerID)>0">
						<Container>
							<xsl:for-each select="ContainerID">
								<CONTAINER_ITEM>
									<DOC_ID>0</DOC_ID>
									<ContainerID><xsl:value-of select="."/></ContainerID>
								</CONTAINER_ITEM>
							</xsl:for-each>	
						</Container>
					</xsl:if>
					<DispatchCountryCode><xsl:value-of select="../DispatchCountryCode"/></DispatchCountryCode>
					<DispatchCountryName><xsl:value-of select="../DispatchCountryName"/></DispatchCountryName>
					<TradingCountryCode><xsl:value-of select="../DispatchCountryCode"/></TradingCountryCode>
					<TradingCountryName><xsl:value-of select="../DispatchCountryName"/></TradingCountryName>
					<DestinationCountryCode><xsl:value-of select="../DestinationCountryCode"/></DestinationCountryCode>
					<DestinationCountryName><xsl:value-of select="../DestinationCountryName"/></DestinationCountryName>
					<InvoiceName><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='04021']/PrDocumentName"/></InvoiceName>
					<xsl:choose>
						<xsl:when test="string-length($NumDoc)>0 or string-length($DatDoc)>0">
							<RegNum><xsl:value-of select="$NumDoc"/></RegNum>
							<xsl:if test="string-length($DatDoc)>0">
								<RegDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></RegDate>
							</xsl:if>	
						</xsl:when>
						<xsl:otherwise>
							<RegNum><xsl:value-of select="$PosSh"/></RegNum>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="string-length($NumCmr)>0">
							<RegNumBill><xsl:value-of select="$NumCmr"/></RegNumBill>
							<SMGS><xsl:value-of select="$NumCmr"/></SMGS>
						</xsl:when>
						<xsl:otherwise>
							<RegNumBill><xsl:value-of select="$PosSh"/></RegNumBill>
							<SMGS><xsl:value-of select="$PosSh"/></SMGS>
						</xsl:otherwise>	
					</xsl:choose>	
					<xsl:if test="string-length(CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentNumber)>0">
						<ContractName><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentName"/></ContractName>
						<ContractNum><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentNumber"/></ContractNum>
						<ContractDate><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='03011']/PrDocumentDate"/></ContractDate>
					</xsl:if>
					<PlacesQuantity><xsl:value-of select="sum(TIRGoods/PlacesInfo/PakingQuantity)"/></PlacesQuantity>
				</INVOICE_ITEM>
			</INVOICE>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:key use="concat(./PrDocumentNumber,./PrDocumentDate,./PresentedDocumentModeCode)" name="TirDoc" match="//PresentedDocuments"/>
	
	<xsl:template match="PresentedDocuments">
		<xsl:param name="Doc"/>
		<xsl:variable name="NumDoc" select="PrDocumentNumber"/>
		<xsl:variable name="DatDoc" select="PrDocumentDate"/>
		<xsl:variable name="TypeDoc" select="PresentedDocumentModeCode"/>		
		<CMRENCLOSEDDOCUMENT_ITEM>
			<DOC_ID>0</DOC_ID>
			<PrDocumentName><xsl:value-of select="PrDocumentName"/></PrDocumentName>
			<PrDocumentNumber><xsl:value-of select="$NumDoc"/></PrDocumentNumber>
			<PrDocumentDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></PrDocumentDate>
			<ModeCode><xsl:value-of select="$TypeDoc"/></ModeCode>
		</CMRENCLOSEDDOCUMENT_ITEM>
	</xsl:template>	
	
	<xsl:key use="./DestinationCustomsCode" name="DistCust" match="//TIRShipment/Destination"/>
	<xsl:template match="TIRShipment/Destination">
		<xsl:variable name="CustCode" select="DestinationCustomsCode"/>
		<CUSTOMPLACE_ITEM>
			<DOC_ID>0</DOC_ID>
			<Destination><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CustCode]/Name"/></Destination>
			<TotalPlacesQuantity><xsl:value-of select="sum(//TIRShipment[Destination/DestinationCustomsCode=$CustCode]/TotalPlacesQuantity)"/></TotalPlacesQuantity>
		</CUSTOMPLACE_ITEM>
	</xsl:template>

	<xsl:key use="./." name="ContNum" match="//TIRShipment/ContainerID"/>	
	<xsl:template match="TIRShipment/ContainerID">
		<CMRCONT_ITEM>
			<DOC_ID>0</DOC_ID>
			<ContainerID><xsl:value-of select="."/></ContainerID>
		</CMRCONT_ITEM>
	</xsl:template>
	
	<xsl:template match="/">
		<xsl:apply-templates select="//CUTIR_Carnet"/>
	</xsl:template>
	
	<xsl:template match="CUTIR_Carnet">
		<Package>
			<xsl:for-each select="//TIRShipment">
				<xsl:variable name="PosShip" select="position()"/>
				<xsl:variable name="NumDoc" select="../CUPresentedDocuments[PresentedDocumentModeCode='02015']/PrDocumentNumber"/>
				<xsl:variable name="DatDoc" select="../CUPresentedDocuments[PresentedDocumentModeCode='02015']/PrDocumentDate"/>
				<xsl:variable name="InvCou" select="count(//CUPresentedDocuments[generate-id(.)=generate-id(key('InvoiceDoc',concat(./PrDocumentNumber,./PrDocumentDate))) and PresentedDocumentModeCode='04021'])"/>
				<xsl:variable name="PackCou" select="count(//CUPresentedDocuments[generate-id(.)=generate-id(key('PackListDoc',concat(./PrDocumentNumber,./PrDocumentDate))) and PresentedDocumentModeCode='00000'])"/>
				<xsl:choose>
					<xsl:when test="$InvCou>0">
						<xsl:apply-templates select="//CUPresentedDocuments[generate-id(.)=generate-id(key('InvoiceDoc',concat(./PrDocumentNumber,./PrDocumentDate))) and PresentedDocumentModeCode='04021']">
							<xsl:with-param name="Doc" select="0"/>
							<xsl:with-param name="NumCmr" select="$NumDoc"/>
							<xsl:with-param name="DatCmr" select="$DatDoc"/>
							<xsl:with-param name="PosSh" select="$PosShip"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="Invoice">
							<xsl:with-param name="NumCmr" select="$NumDoc"/>
							<xsl:with-param name="DatCmr" select="$DatDoc"/>
							<xsl:with-param name="NumDoc"/>
							<xsl:with-param name="DatDoc"/>
							<xsl:with-param name="PosSh" select="$PosShip"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$PackCou>0">
						<xsl:apply-templates select="//CUPresentedDocuments[generate-id(.)=generate-id(key('PackListDoc',concat(./PrDocumentNumber,./PrDocumentDate))) and PresentedDocumentModeCode='00000']">
							<xsl:with-param name="Doc" select="0"/>
							<xsl:with-param name="NumCmr" select="$NumDoc"/>
							<xsl:with-param name="DatCmr" select="$DatDoc"/>
							<xsl:with-param name="PosSh" select="$PosShip"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="count(TIRGoods/PackingInfo)>0">
						<xsl:call-template name="PackL">
							<xsl:with-param name="NumCmr" select="$NumDoc"/>
							<xsl:with-param name="DatCmr" select="$DatDoc"/>
							<xsl:with-param name="NumDoc"/>
							<xsl:with-param name="DatDoc"/>
							<xsl:with-param name="PosSh" select="$PosShip"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<CMR ctmtd:CfgName="CMR.CFG.XML" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
					<CMR_ITEM>
						<DOC_ID>0</DOC_ID>
						<pi>2</pi>
						<LanguageCode>RU</LanguageCode>
						<GoodsQuantity><xsl:value-of select="count(TIRGoods/GoodsTNVEDCode)"/></GoodsQuantity>
						<RegNum><xsl:value-of select="$NumDoc"/></RegNum>
						<xsl:if test="string-length($DatDoc)>0">
							<RegDate><xsl:value-of select="concat($DatDoc,'T00:00:00.0Z')"/></RegDate>
						</xsl:if>
						<Place><xsl:value-of select="CUPresentedDocuments[PresentedDocumentModeCode='02015']/OrganizationName"/></Place>
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Consignor_'"/>
							<xsl:with-param name="NodeName" select="TIRConsignor"/>
							<xsl:with-param name="NodeAdd" select="TIRConsignor/Address"/>
						</xsl:call-template> 
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Consignee_'"/>
							<xsl:with-param name="NodeName" select="TIRConsignee"/>
							<xsl:with-param name="NodeAdd" select="TIRConsignee/Address"/>
						</xsl:call-template>
						<TIRHolder><xsl:value-of select="../Carrier/TIRHolderID"/></TIRHolder>
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Carrier_'"/>
							<xsl:with-param name="NodeName" select="../Carrier"/>
							<xsl:with-param name="NodeAdd" select="../Carrier/Address"/>
						</xsl:call-template>
						<xsl:call-template name="AddressOrg">
							<xsl:with-param name="Pref" select="'DeliveryPlace_'"/>
							<xsl:with-param name="NodeAdd" select="Destination/Address"/>
						</xsl:call-template>
						<CMREnclosedDocument>
							<xsl:choose>
								<xsl:when test="count(../CUPresentedDocuments[PresentedDocumentModeCode!='02015'])>0">
									<xsl:for-each select="../CUPresentedDocuments[PresentedDocumentModeCode!='02015']">
										<CMRENCLOSEDDOCUMENT_ITEM>
											<DOC_ID>0</DOC_ID>
											<DocumentName>
												<xsl:choose>
													<xsl:when test="string-length(PrDocumentName)>0">
														<xsl:value-of select="PrDocumentName"/>													
													</xsl:when>
													<xsl:otherwise>Накладная CMR</xsl:otherwise>
												</xsl:choose>
											</DocumentName>
											<DocumentNumber><xsl:value-of select="PrDocumentNumber"/></DocumentNumber>
											<xsl:if test="string-length(PrDocumentDate)>0">
												<DocumentDate><xsl:value-of select="concat(PrDocumentDate,'T00:00:00.0Z')"/></DocumentDate>
											</xsl:if>
											<ModeCode><xsl:value-of select="PresentedDocumentModeCode"/></ModeCode>
										</CMRENCLOSEDDOCUMENT_ITEM>
									</xsl:for-each>							
								</xsl:when>
								<xsl:otherwise>
									<CMRENCLOSEDDOCUMENT_ITEM>
										<DOC_ID>0</DOC_ID>
										<DocumentName>Invoice</DocumentName>
										<DocumentNumber><xsl:value-of select="$PosShip"/></DocumentNumber>
										<ModeCode>04021</ModeCode>
									</CMRENCLOSEDDOCUMENT_ITEM>
								</xsl:otherwise>		
							</xsl:choose>
						</CMREnclosedDocument>
						<CMRGoods>
							<xsl:for-each select="TIRGoods">
								<CMRGOODS_ITEM>
									<DOC_ID>0</DOC_ID>
									<GoodsDescription>
										<xsl:for-each select="GoodsDescription">
											<xsl:value-of select="."/>
										</xsl:for-each>
									</GoodsDescription>
									<PlacesDescription><xsl:value-of select="PlacesInfo/PackingCode"/></PlacesDescription>
									<GoodsNumeric><xsl:value-of select="position()"/></GoodsNumeric>
									<GoodsNomenclatureCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsNomenclatureCode>
									<PlacesCode><xsl:value-of select="PlacesInfo/PackingCode"/></PlacesCode>
									<PlacesQuantity><xsl:value-of select="PlacesInfo/PakingQuantity"/></PlacesQuantity>
									<TotalCost><xsl:value-of select="InvoicedCost"/></TotalCost>
									<GoodsQuantity><xsl:value-of select="SupplementaryGoodsQuantity"/></GoodsQuantity>
									<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
								</CMRGOODS_ITEM>
							</xsl:for-each>
						</CMRGoods>
						<xsl:if test="count(ContainerID)>0">
							<CMRcont>
								<xsl:for-each select="ContainerID">
									<xsl:sort select="."/>
									<CMRCONT_ITEM>
										<DOC_ID>0</DOC_ID>
										<ContainerID><xsl:value-of select="."/></ContainerID>
									</CMRCONT_ITEM>
								</xsl:for-each>	
							</CMRcont>
						</xsl:if>
						<GrossWeightQuantity><xsl:value-of select="sum(TIRGoods/GrossWeightQuantity)"/></GrossWeightQuantity>
						<xsl:variable name="CodeTO" select="Destination/DestinationCustomsCode"/>
						<DestinationOfficeName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CodeTO]/Name"/></DestinationOfficeName>
						<DestinationOfficeIdentifier><xsl:value-of select="$CodeTO"/></DestinationOfficeIdentifier>
						<xsl:variable name="CountryAB" select="Destination/Address/CountryCode"/>						
						<DestinationOfficeCountryCode><xsl:value-of select="$CountryAB"/></DestinationOfficeCountryCode>
						<DestinationOfficeCountryName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CountryAB]/Name"/></DestinationOfficeCountryName>
						<DestinationOfficeCity><xsl:value-of select="Destination/Address/City"/></DestinationOfficeCity>
						<DestinationOfficeStreetHouse><xsl:value-of select="Destination/Address/StreetHouse"/></DestinationOfficeStreetHouse>
						<CurrencyCode><xsl:value-of select="TIRGoods[1]/InvoicedCostCurrencyCode"/></CurrencyCode>
						
						<PrimeMoverStateSignID><xsl:value-of select="../CUTransport/TransportMeans[1]/TransportIdentifier"/></PrimeMoverStateSignID>
						<TrailerStateSignID><xsl:value-of select="../CUTransport/TransportMeans[2]/TransportIdentifier"/></TrailerStateSignID>
						<TrailerStateSignID2><xsl:value-of select="../CUTransport/TransportMeans[3]/TransportIdentifier"/></TrailerStateSignID2>
						<VINID><xsl:value-of select="../CUTransport/TransportMeans[1]/VIN"/></VINID>
						<VINID2><xsl:value-of select="../CUTransport/TransportMeans[2]/VIN"/></VINID2>
						<VINID3><xsl:value-of select="../CUTransport/TransportMeans[3]/VIN"/></VINID3>
						<TransportMeansNationalityCode><xsl:value-of select="../CUTransport/TransportNationalityCode"/></TransportMeansNationalityCode>
						
						<TakingCargoPlace_CountryCode><xsl:value-of select="../DispatchCountryCode"/></TakingCargoPlace_CountryCode>
						<TakingCargoPlace_CountryName><xsl:value-of select="../DispatchCountryName"/></TakingCargoPlace_CountryName>

						<ObCena><xsl:value-of select="format-number(sum(TIRGoods/InvoicedCost),'#.00')"/></ObCena>
					</CMR_ITEM>
				</CMR>			
			</xsl:for-each>
			<xsl:if test="count(Carrier/CUDriverInformation)>0 or string-length(TIRDeclarant/OrganizationName)>0">
				<APPENDIX ctmtd:CfgName="APPENDIX.CFG.XML" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
					<APPENDIX_ITEM>
						<DOC_ID>0</DOC_ID>
						<xsl:if test="count(Carrier/CUDriverInformation)>0">
							<Drivers>
								<xsl:for-each select="Carrier/CUDriverInformation">
									<DRIVERS_ITEM>
										<DOC_ID>0</DOC_ID>
										<PersonName><xsl:value-of select="PersonName"/></PersonName>
										<PersonSurname><xsl:value-of select="PersonSurname"/></PersonSurname>
										<PersonMiddleName><xsl:value-of select="PersonMiddleName"/></PersonMiddleName>
										<PersonPost><xsl:value-of select="PersonPost"/></PersonPost>
										<IndentityCardCode><xsl:value-of select="IdentityCard/IdentityCardCode"/></IndentityCardCode>
										<IdentityCardName><xsl:value-of select="IdentityCard/IdentityCardName"/></IdentityCardName>
										<IdentityCardSeries><xsl:value-of select="IdentityCard/IdentityCardSeries"/></IdentityCardSeries>
										<IdentityCardNumder><xsl:value-of select="IdentityCard/IdentityCardNumber"/></IdentityCardNumder>
										<IndentityCardDate><xsl:value-of select="IdentityCard/IdentityCardDate"/></IndentityCardDate>
										<OrganizationName><xsl:value-of select="IdentityCard/OrganizationName"/></OrganizationName>
										<CountryCode><xsl:value-of select="RegCountryCode"/></CountryCode>
									</DRIVERS_ITEM>
								</xsl:for-each>
							</Drivers>
						</xsl:if> 
						<xsl:if test="string-length(TIRDeclarant/OrganizationName)>0">
							<Declarant_Principal>1</Declarant_Principal>
							<Principal_Name><xsl:value-of select="TIRDeclarant/OrganizationName"/></Principal_Name>
							<Principal_ShortName><xsl:value-of select="TIRDeclarant/ShortName"/></Principal_ShortName>
							<Principal_PostalCode><xsl:value-of select="TIRDeclarant/Address/PostalCode"/></Principal_PostalCode>
							<Principal_CountryCode><xsl:value-of select="TIRDeclarant/Address/CountryCode"/></Principal_CountryCode>
							<Principal_CountryName><xsl:value-of select="TIRDeclarant/Address/CounryName"/></Principal_CountryName>
							<Principal_Region><xsl:value-of select="TIRDeclarant/Address/Region"/></Principal_Region>
							<Principal_City><xsl:value-of select="TIRDeclarant/Address/City"/></Principal_City>
							<Principal_StreetHouse><xsl:value-of select="TIRDeclarant/Address/StreetHouse"/></Principal_StreetHouse>
						</xsl:if>
					</APPENDIX_ITEM>
				</APPENDIX>
			</xsl:if>
			<TIR ctmtd:CfgName="TIR.CFG.XML" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
				<TIR_ITEM>
					<DOC_ID>0</DOC_ID>
					<pi>2</pi>
					<TMNumber><xsl:value-of select="CUTransport/TransportMeans[1]/TransportIdentifier"/></TMNumber>
					<TrailerNumber><xsl:value-of select="CUTransport/TransportMeans[2]/TransportIdentifier"/></TrailerNumber>
					<TrailerNumber2><xsl:value-of select="CUTransport/TransportMeans[3]/TransportIdentifier"/></TrailerNumber2>
					<VINID><xsl:value-of select="CUTransport/TransportMeans[1]/VIN"/></VINID>
					
					<DispatchCountryName><xsl:value-of select="DispatchCountryName"/></DispatchCountryName>
					<DispatchCountryCode><xsl:value-of select="DispatchCountryCode"/></DispatchCountryCode>
					<DestinationCountryName><xsl:value-of select="DestinationCountryName"/></DestinationCountryName>
					<DestinationCountryCode><xsl:value-of select="DestinationCountryCode"/></DestinationCountryCode>
					<DestinationCustoms><xsl:value-of select="TIRShipment/Destination/DestinationCustomsCode"/></DestinationCustoms>

					<xsl:variable name="TrNCode" select="CUTransport/TransportNationalityCode"/>
					<TransportMeansNationalityCode><xsl:value-of select="$TrNCode"/></TransportMeansNationalityCode>
					<TransportMeansNationalityName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$TrNCode]/Name"/></TransportMeansNationalityName>
					<TransportModeCode><xsl:value-of select="CUTransport/TransportModeCode"/></TransportModeCode>
					<GoodsQuantity><xsl:value-of select="sum(//TIRGoods/SupplementaryGoodsQuantity)"/></GoodsQuantity>
					
					<TIRID><xsl:value-of select="TIRIdentifier/TIRID"/></TIRID>
					<TIRWhitePageNumber>
						<xsl:choose>
							<xsl:when test="string-length(TIRIdentifier/TIRWhitePageNumber)=1">
								<xsl:value-of select="concat('0',TIRIdentifier/TIRWhitePageNumber)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="TIRIdentifier/TIRWhitePageNumber"/>
							</xsl:otherwise>
						</xsl:choose>
					</TIRWhitePageNumber>
					<TIRHolder><xsl:value-of select="Carrier/TIRHolderID"/></TIRHolder>
					<TIRSeries><xsl:value-of select="TIRIdentifier/TIRSeries"/></TIRSeries>
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Consignor_'"/>
						<xsl:with-param name="NodeName" select="TIRShipment[1]/TIRConsignor"/>
						<xsl:with-param name="NodeAdd" select="TIRShipment[1]/TIRConsignor/Address"/>
					</xsl:call-template>
					<xsl:call-template name="OrgPackage">
						<xsl:with-param name="Pref" select="'Carrier_'"/>
						<xsl:with-param name="NodeName" select="Carrier"/>
						<xsl:with-param name="NodeAdd" select="Carrier/Address"/>
					</xsl:call-template>	
					<CMREnclosedDocument>
						<xsl:for-each select="CUPresentedDocuments">
							<CMRENCLOSEDDOCUMENT_ITEM>
								<DOC_ID>0</DOC_ID>
								<PrDocumentName><xsl:value-of select="PrDocumentName"/></PrDocumentName>
								<PrDocumentNumber><xsl:value-of select="PrDocumentNumber"/></PrDocumentNumber>
								<xsl:if test="string-length(PrDocumentDate)>0">
									<PrDocumentDate><xsl:value-of select="concat(PrDocumentDate,'T00:00:00.0Z')"/></PrDocumentDate>
								</xsl:if>
								<ModeCode><xsl:value-of select="PresentedDocumentModeCode"/></ModeCode>
							</CMRENCLOSEDDOCUMENT_ITEM>
						</xsl:for-each>							
						<xsl:if test="count(CUPresentedDocuments[PresentedDocumentModeCode!='02015'])=0">
							<xsl:for-each select="//TIRShipment">
								<CMRENCLOSEDDOCUMENT_ITEM>
									<DOC_ID>0</DOC_ID>
									<PrDocumentName>Invoice</PrDocumentName>
									<PrDocumentNumber><xsl:value-of select="position()"/></PrDocumentNumber>
									<ModeCode>04021</ModeCode>
								</CMRENCLOSEDDOCUMENT_ITEM>
							</xsl:for-each>	
						</xsl:if>		
					</CMREnclosedDocument>
					<CustomPlace>
						<xsl:apply-templates select="//TIRShipment/Destination[generate-id(.)=generate-id(key('DistCust',./DestinationCustomsCode))]"/>
					</CustomPlace>
					<xsl:if test="count(//TIRShipment/ContainerID)>0">
						<CMRcont>
							<xsl:apply-templates select="//TIRShipment/ContainerID[generate-id(.)=generate-id(key('ContNum',./.))]"/>
						</CMRcont>
					</xsl:if>
					<CMRGoods>
						<xsl:for-each select="//TIRGoods">
							<CMRGOODS_ITEM>
								<DOC_ID>0</DOC_ID>
								<GoodsDescription>
									<xsl:for-each select="GoodsDescription">
										<xsl:value-of select="."/>
									</xsl:for-each>
								</GoodsDescription>
								<GoodsNumeric><xsl:value-of select="position()"/></GoodsNumeric>
								<xsl:variable name="OrgC" select="OriginCountryCode"/>
								<GoodsNomenclatureCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsNomenclatureCode>
								<GoodsQuantity><xsl:value-of select="SupplementaryGoodsQuantity"/></GoodsQuantity>
								<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
								<CMRGoodsPackingInfo>
									<xsl:for-each select="PlacesInfo">
										<CMRGOODSPACKINGINFO_ITEM>
											<DOC_ID>0</DOC_ID>
											<PlacesCode><xsl:value-of select="PackingCode"/></PlacesCode>
											<PlacesDescription><xsl:value-of select="PackingDescription"/></PlacesDescription>
											<PlacesQuantity><xsl:value-of select="PakingQuantity"/></PlacesQuantity>
										</CMRGOODSPACKINGINFO_ITEM>
									</xsl:for-each>
								</CMRGoodsPackingInfo>
							</CMRGOODS_ITEM>
						</xsl:for-each>
					</CMRGoods>	
					<GrossWeightQuantity><xsl:value-of select="format-number(sum(//TIRGoods/GrossWeightQuantity),'#.000')"/></GrossWeightQuantity>
					<DestinationOfficeIdentifier><xsl:value-of select="TIRShipment/Destination/DestinationCustomsCode"/></DestinationOfficeIdentifier>
					<TotalGrossWeight><xsl:value-of select="format-number(sum(//TIRGoods/GrossWeightQuantity),'#.000')"/></TotalGrossWeight>
				</TIR_ITEM>
			</TIR>
			
		</Package>
	</xsl:template>
</xsl:stylesheet>
