<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:import href="../../COMMON/FunctionForXsl.xsl"/>
	<xsl:output method="xml"/>
	<xsl:template name="SumStr">
		<xsl:param name="SumValue"/>
		<xsl:variable name="SumVal1" select="format-number(substring-before(format-number($SumValue,'#.000'),'.'),'#')"/>
		<xsl:variable name="SumVal2">
			<xsl:call-template name='RecurseSumWords'>
				<xsl:with-param name='Value' select='$SumVal1'/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="SumVal3" select="format-number(format-number($SumValue,'#.000')-$SumVal1,'0.000')"/>
		<xsl:choose>
			<xsl:when test="$SumVal3!=0">
				<xsl:value-of select="concat($SumVal2,' ', substring-after(string($SumVal3),'.'))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$SumVal2"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="OrgPackage">
		<xsl:param name="Pref"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="NodeAdd"/>
		<xsl:for-each select="$NodeName">
			<xsl:element name="{concat($Pref,'Name')}"><xsl:value-of select="OrganizationName"/></xsl:element>
			<xsl:element name="{concat($Pref,'ShortName')}"><xsl:value-of select="OrganizationName"/></xsl:element>
			<xsl:choose>
				<xsl:when test="count(RFOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'OGRN')}"><xsl:value-of select="RFOrganizationFeatures/OGRN"/></xsl:element>
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RFOrganizationFeatures/INN"/></xsl:element>
					<xsl:element name="{concat($Pref,'KPP')}"><xsl:value-of select="RFOrganizationFeatures/KPP"/></xsl:element>
				</xsl:when>
				<xsl:when test="count(RBOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RBOrganizationFeatures/INN"/></xsl:element>
				</xsl:when>
				<xsl:when test="count(RKOrganizationFeatures)>0">
					<xsl:element name="{concat($Pref,'OGRN')}"><xsl:value-of select="RKOrganizationFeatures/BIN"/></xsl:element>
					<xsl:element name="{concat($Pref,'INN')}"><xsl:value-of select="RKOrganizationFeatures/INN"/></xsl:element>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
		<xsl:call-template name="AddressOrg">
			<xsl:with-param name="Pref" select="$Pref"/>
			<xsl:with-param name="NodeAdd" select="$NodeAdd"/>
		</xsl:call-template> 
	</xsl:template>	
   <xsl:template name="AddressOrg">
   		<xsl:param name="Pref"/>
		<xsl:param name="NodeAdd"/>
   		<xsl:for-each select="$NodeAdd">
			<xsl:element name="{concat($Pref,'PostalCode')}"><xsl:value-of select="PostalCode"/></xsl:element>
			<xsl:element name="{concat($Pref,'CountryCode')}"><xsl:value-of select="CountryCode"/></xsl:element>
			<xsl:variable name="CrC" select="CountryCode"/>
			<xsl:element name="{concat($Pref,'CountryName')}"><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CrC]/Name"/></xsl:element>
			<xsl:element name="{concat($Pref,'Region')}"><xsl:value-of select="Region"/></xsl:element>
			<xsl:element name="{concat($Pref,'City')}"><xsl:value-of select="City"/></xsl:element>
			<xsl:element name="{concat($Pref,'StreetHouse')}"><xsl:value-of select="StreetHouse"/></xsl:element>
		</xsl:for-each>		
</xsl:template>

	<xsl:template name="Invoice">
		<xsl:param name="PosSh"/>
		<INVOICE ctmtd:CfgName="invoice.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<INVOICE_ITEM>
				<DOC_ID>0</DOC_ID>
				<xsl:variable name="Val" select="//GoodsInform/Goods[1]/CurrencyCode"/> 
				<CurrencyCode><xsl:value-of select="$Val"/></CurrencyCode>
				<CurrencyNumber><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$Val]/Code"/></CurrencyNumber>
				<CurrencyName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Currency_ITEM[ABBR=$Val]/Name"/></CurrencyName>
				<GrossWeightQuantity><xsl:value-of select="sum(//Goods/GrossWeightQuantity)"/></GrossWeightQuantity>
				<NetWeightQuantity><xsl:value-of select="sum(//Goods/NetWeightQuantity)"/></NetWeightQuantity>
				<GCost><xsl:value-of select="sum(//Goods/InvoicedCost)"/></GCost>
				<OtherChargesName>Сумма прочих расходов</OtherChargesName>
				<TotalCost><xsl:value-of select="sum(//Goods/InvoicedCost)"/></TotalCost>
				<TotalSign>						
					<xsl:call-template name='SumStr'>
						<xsl:with-param name='SumValue' select="sum(//Goods/InvoicedCost)"/>
					</xsl:call-template>
					<xsl:value-of select="concat(' ',$Val)"/>
				</TotalSign>
				<PlacesQuantity><xsl:value-of select="sum(//Goods/GoodsPackaging/PakageQuantity)"/></PlacesQuantity>
				<xsl:call-template name="OrgPackage">
					<xsl:with-param name="Pref" select="'Consignor_'"/>
					<xsl:with-param name="NodeName" select="//Consignor"/>
					<xsl:with-param name="NodeAdd" select="//Consignor/Address"/>
				</xsl:call-template> 
				<xsl:call-template name="OrgPackage">
					<xsl:with-param name="Pref" select="'Consignee_'"/>
					<xsl:with-param name="NodeName" select="//Consignee"/>
					<xsl:with-param name="NodeAdd" select="//Consignee/Address"/>
				</xsl:call-template> 
				<INVOICEGoods >
					<xsl:for-each select="//Goods">
						<INVOICEGOODS_ITEM>
							<DOC_ID>0</DOC_ID>
							<GoodsCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsCode>
							<GoodsDescription>
								<xsl:for-each select="GoodsDescription">
									<xsl:value-of select="."/>
									<xsl:if test="position()!=last()">
										<xsl:text> </xsl:text>
									</xsl:if>
								</xsl:for-each>
							</GoodsDescription>
							<GoodsQuantity><xsl:value-of select="GoodsMeasureQuantity/GoodsQuantity"/></GoodsQuantity>
							<MeasureUnitQualifierName><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierName"/></MeasureUnitQualifierName>
							<MeasureUnitQualifierCode><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierCode"/></MeasureUnitQualifierCode>
							<PlacesQuantity><xsl:value-of select="GoodsPackaging/PakageQuantity"/></PlacesQuantity>
							<PlacesDescription><xsl:value-of select="GoodsPackaging/CargoDescription"/></PlacesDescription>
							<PlacesCode><xsl:value-of select="GoodsPackaging/CargoCode"/></PlacesCode>
							<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
							<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
							<TotalCost><xsl:value-of select="InvoicedCost"/></TotalCost>
							<!--<xsl:variable name="OrgC" select="OriginCountryCode"/>
							<OriginCountryCode><xsl:value-of select="$OrgC"/></OriginCountryCode>
							<OriginCountryNumber><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$OrgC]/Code"/></OriginCountryNumber>
							<OriginCountry><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$OrgC]/Name"/></OriginCountry>-->
						</INVOICEGOODS_ITEM>
					</xsl:for-each>	
				</INVOICEGoods>
				<Carriage>
					<CARRIAGE_ITEM>
						<DOC_ID>0</DOC_ID>
						<CarriageId><xsl:value-of select="//ShippingInformation/BorderTransport/TransportIdentifier"/></CarriageId>
					</CARRIAGE_ITEM>
					<xsl:if  test="string-length(//ShippingInformation/BorderTransport/TrailerIdentifier)>0">
						<CARRIAGE_ITEM>
							<DOC_ID>0</DOC_ID>
							<CarriageId><xsl:value-of select="//ShippingInformation/BorderTransport/TrailerIdentifier"/></CarriageId>
						</CARRIAGE_ITEM>	
					</xsl:if>
					<xsl:if  test="string-length(//ShippingInformation/BorderTransport/SecondTrailerIdentifier)>0">
						<CARRIAGE_ITEM>
							<DOC_ID>0</DOC_ID>
							<CarriageId><xsl:value-of select="//ShippingInformation/BorderTransport/SecondTrailerIdentifier"/></CarriageId>
						</CARRIAGE_ITEM>	
					</xsl:if>						
				</Carriage>
				<xsl:if test="count(//Goods/ContainerNumbers)>0">
					<Container>
						<xsl:for-each select="//Goods[not(ContainerNumbers =preceding::*/ContainerNumbers)]/ContainerNumbers">
							<xsl:sort select="."/>
							<CONTAINER_ITEM>
								<DOC_ID>0</DOC_ID>
								<ContainerID><xsl:value-of select="."/></ContainerID>
							</CONTAINER_ITEM>
						</xsl:for-each>	
					</Container>
				</xsl:if>
				<DispatchCountryCode><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryACode"/></DispatchCountryCode>
				<DispatchCountryName><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryName"/></DispatchCountryName>
				<TradingCountryCode><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryACode"/></TradingCountryCode>
				<TradingCountryName><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryName"/></TradingCountryName>
				<DestinationCountryCode><xsl:value-of select="//ShippingInformation/DestinationCountry/CountryACode"/></DestinationCountryCode>
				<DestinationCountryName><xsl:value-of select="//ShippingInformation/DestinationCountry/CountryName"/></DestinationCountryName>
				<DeadLine><xsl:value-of select="//ShippingInformation/DateLimit"/></DeadLine>
				<RegNum><xsl:value-of select="$PosSh"/></RegNum>
				<RegNumBill><xsl:value-of select="$PosSh"/></RegNumBill>
				<SMGS><xsl:value-of select="$PosSh"/></SMGS>
			</INVOICE_ITEM>
		</INVOICE>
	</xsl:template>
	
	<xsl:template name="PackList">
		<xsl:param name="PosSh"/>
		<PACKINGLIST ctmtd:CfgName="PackingList.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<PACKINGLIST_ITEM>
				<DOC_ID>0</DOC_ID>
				<DocName>Отгрузочный (упаковочный) лист</DocName>
				<RegNum><xsl:value-of select="$PosSh"/></RegNum>
				<GrossWeightQuantity><xsl:value-of select="sum(//Goods/GrossWeightQuantity)"/></GrossWeightQuantity>
				<NetWeightQuantity><xsl:value-of select="sum(//Goods/NetWeightQuantity)"/></NetWeightQuantity>
				<xsl:call-template name="OrgPackage">
					<xsl:with-param name="Pref" select="'Consignor_'"/>
					<xsl:with-param name="NodeName" select="//Consignor"/>
					<xsl:with-param name="NodeAdd" select="//Consignor/Address"/>
				</xsl:call-template> 
				<xsl:call-template name="OrgPackage">
					<xsl:with-param name="Pref" select="'Consignee_'"/>
					<xsl:with-param name="NodeName" select="//Consignee"/>
					<xsl:with-param name="NodeAdd" select="//Consignee/Address"/>
				</xsl:call-template> 
				<InvoiceNum><xsl:value-of select="$PosSh"/></InvoiceNum>
				<PACKINGLISTGoods>
					<xsl:for-each select="//Goods">
						<PACKINGLISTGOODS_ITEM>
							<DOC_ID>0</DOC_ID>
							<PlacesQuantity><xsl:value-of select="GoodsPackaging/PakageQuantity"/></PlacesQuantity>
							<PlacesDescription><xsl:value-of select="GoodsPackaging/CargoDescription"/></PlacesDescription>
							<PackingCode><xsl:value-of select="GoodsPackaging/CargoCode"/></PackingCode>		
							<GoodsDescription>
								<xsl:for-each select="GoodsDescription">
									<xsl:value-of select="."/>
									<xsl:if test="position()!=last()">
										<xsl:text> </xsl:text>
									</xsl:if>
								</xsl:for-each>
							</GoodsDescription>
							<GoodsQuantity><xsl:value-of select="GoodsMeasureQuantity/GoodsQuantity"/></GoodsQuantity>
							<MeasureUnitQualifierName><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierName"/></MeasureUnitQualifierName>
							<MeasureUnitQualifierCode><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierCode"/></MeasureUnitQualifierCode>	
							<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
							<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
							<PACKINGLISTGoodsPlaces>
								<xsl:for-each select="GoodsPackaging">
									<PACKINGLISTGOODSPLACES_ITEM>
										<DOC_ID>0</DOC_ID>
										<PlacesQuantity><xsl:value-of select="PakageQuantity"/></PlacesQuantity>
										<PlacesDescription><xsl:value-of select="CargoDescription"/></PlacesDescription>
										<PlacesCode><xsl:value-of select="CargoCode"/></PlacesCode>		
									</PACKINGLISTGOODSPLACES_ITEM>
								</xsl:for-each>
							</PACKINGLISTGoodsPlaces>
							<PACKINGLISTGoodsPackingInfo>
								<xsl:for-each select="GoodsPackaging/PackingInformation">
									<PACKINGLISTGOODSPACKINGINFO_ITEM>
										<DOC_ID>0</DOC_ID>
										<PackingCode><xsl:value-of select="PackingCode"/></PackingCode>
										<xsl:variable name="PackC" select="PackingCode"/>
										<PackingDescription><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PackC]/Name"/></PackingDescription>
										<PackingMark><xsl:value-of select="PackingMark"/></PackingMark>
										<PackingQuantity><xsl:value-of select="PakingQuantity"/></PackingQuantity>
									</PACKINGLISTGOODSPACKINGINFO_ITEM>
								</xsl:for-each>	
							</PACKINGLISTGoodsPackingInfo>
						</PACKINGLISTGOODS_ITEM>
					</xsl:for-each>
				</PACKINGLISTGoods>	
				<PACKINGLISTTotalPlaces>
					<xsl:apply-templates select="//GoodsPackaging[generate-id(.)=generate-id(key('Paking',./CargoCode))]"/>
				</PACKINGLISTTotalPlaces>
			</PACKINGLIST_ITEM>
		</PACKINGLIST>
	</xsl:template>		
	
<xsl:key use="./CargoCode" name="Paking" match="//GoodsPackaging"/>
	<xsl:template match="//GoodsPackaging">
		<xsl:variable name="PackC1" select="CargoCode"/>
		<PACKINGLISTTOTALPLACES_ITEM>
			<DOC_ID>0</DOC_ID>
				<PlacesQuantity><xsl:value-of select="sum(//Goods/GoodsPackaging/PakageQuantity)"/></PlacesQuantity>
				<PlacesDescription><xsl:value-of select="$PackC1"/></PlacesDescription>
				<PackingCode><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Packing_ITEM[ID=$PackC1]/Name"/></PackingCode>
		</PACKINGLISTTOTALPLACES_ITEM>
	</xsl:template>
	<xsl:template name="Apendix">
		<APPENDIX ctmtd:CfgName="APPENDIX.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<APPENDIX_ITEM>
				<DOC_ID>0</DOC_ID>
				<DepatureOfficeIdentifier><xsl:value-of select="//GoodsInform/BorderCustoms/Code"/></DepatureOfficeIdentifier>
				<DepatureOfficeName><xsl:value-of select="//GoodsInform/BorderCustoms/OfficeName"/></DepatureOfficeName>
			</APPENDIX_ITEM>
		</APPENDIX>
	</xsl:template>		
	
	<xsl:template match="/">
		<xsl:apply-templates select="//PI_AutoArrive"/>
	</xsl:template>
	
	<xsl:template match="PI_AutoArrive">
		<Package>
			<xsl:for-each select="//GoodsInform">
				<xsl:variable name="PosShip" select="position()"/>
				<xsl:call-template name="Invoice">
					<xsl:with-param name="PosSh" select="$PosShip"/>
				</xsl:call-template>
				<CMR ctmtd:CfgName="CMR.CFG.XML" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
					<CMR_ITEM>
						<DOC_ID>0</DOC_ID>
						<LanguageCode>RU</LanguageCode>
						<GoodsQuantity><xsl:value-of select="count(Goods/GoodsTNVEDCode)"/></GoodsQuantity>
						<RegNum><xsl:value-of select="$PosShip"/></RegNum>
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Consignor_'"/>
							<xsl:with-param name="NodeName" select="../Consignor"/>
							<xsl:with-param name="NodeAdd" select="../Consignor/Address"/>
						</xsl:call-template> 
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Consignee_'"/>
							<xsl:with-param name="NodeName" select="../Consignee"/>
							<xsl:with-param name="NodeAdd" select="../Consignee/Address"/>
						</xsl:call-template>
						<xsl:call-template name="OrgPackage">
							<xsl:with-param name="Pref" select="'Carrier_'"/>
							<xsl:with-param name="NodeName" select="../Carrier"/>
							<xsl:with-param name="NodeAdd" select="../Carrier/Address"/>
						</xsl:call-template>
						<xsl:call-template name="AddressOrg">
							<xsl:with-param name="Pref" select="'DeliveryPlace_'"/>
							<xsl:with-param name="NodeAdd" select="../Consignee/Address"/>
						</xsl:call-template>
						<CMREnclosedDocument> 
							<CMRENCLOSEDDOCUMENT_ITEM>
								<DOC_ID>0</DOC_ID>
								<DocumentName>Invoice</DocumentName>
								<DocumentNumber><xsl:value-of select="$PosShip"/></DocumentNumber>
								<ModeCode>04021</ModeCode>
							</CMRENCLOSEDDOCUMENT_ITEM>
							<xsl:if test="count(Goods/GoodsPackaging/PackingInformation)>0">
								<CMRENCLOSEDDOCUMENT_ITEM>
									<DOC_ID>0</DOC_ID>
									<DocumentName>Отгрузочный (упаковочный) лист</DocumentName>
									<DocumentNumber><xsl:value-of select="$PosShip"/></DocumentNumber>
									<ModeCode>04131</ModeCode>
								</CMRENCLOSEDDOCUMENT_ITEM>			
							</xsl:if>	
						</CMREnclosedDocument>
						<CMRGoods>
							<xsl:for-each select="Goods">
								<CMRGOODS_ITEM>
									<DOC_ID>0</DOC_ID>
									<GoodsDescription>
										<xsl:for-each select="GoodsDescription">
											<xsl:value-of select="."/>
											<xsl:if test="position()!=last()">
												<xsl:text> </xsl:text>
											</xsl:if>
										</xsl:for-each>
									</GoodsDescription>
									<PlacesDescription><xsl:value-of select="concat(GoodsPackaging/CargoCode,',',GoodsPackaging/CargoDescription)"/></PlacesDescription>
									<GoodsNumeric><xsl:value-of select="position()"/></GoodsNumeric>
									<GoodsNomenclatureCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsNomenclatureCode>
									<PlacesCode><xsl:value-of select="GoodsPackaging/CargoCode"/></PlacesCode>
									<PlacesQuantity><xsl:value-of select="GoodsPackaging/PakageQuantity"/></PlacesQuantity>
									<TotalCost><xsl:value-of select="InvoicedCost"/></TotalCost>
									<GoodsQuantity><xsl:value-of select="GoodsMeasureQuantity/GoodsQuantity"/></GoodsQuantity>
									<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
								</CMRGOODS_ITEM>
							</xsl:for-each>
						</CMRGoods>
						<xsl:if test="count(Goods[string-length(ContainerNumbers)>0]/ContainerNumbers)>0">
							<CMRcont>
								<xsl:for-each select="Goods[not(ContainerNumbers =preceding::*/ContainerNumbers)]/ContainerNumbers">
									<xsl:sort select="."/>
									<CMRCONT_ITEM>
										<DOC_ID>0</DOC_ID>
										<ContainerID><xsl:value-of select="."/></ContainerID>
									</CMRCONT_ITEM>
								</xsl:for-each>	
							</CMRcont>
						</xsl:if>
						<GrossWeightQuantity><xsl:value-of select="sum(Goods/GrossWeightQuantity)"/></GrossWeightQuantity>
					
						<DestinationOfficeCountryCode><xsl:value-of select="//ShippingInformation/Destination/CountryACode"/></DestinationOfficeCountryCode>
						<DestinationOfficeCountryName><xsl:value-of select="//ShippingInformation/Destination/CountryName"/></DestinationOfficeCountryName>

						<CurrencyCode><xsl:value-of select="Goods[1]/CurrencyCode"/></CurrencyCode>
						<ActiveTransportIdentifier><xsl:value-of select="//ShippingInformation/BorderTransport[1]/TransportIdentifier"/></ActiveTransportIdentifier>
						<PrimeMoverStateSignID><xsl:value-of select="//ShippingInformation/BorderTransport[1]/TransportIdentifier"/></PrimeMoverStateSignID>
						<TrailerStateSignID><xsl:value-of select="//ShippingInformation/BorderTransport[1]/TrailerIdentifier"/></TrailerStateSignID>
						<TrailerStateSignID2><xsl:value-of select="//ShippingInformation/BorderTransport[1]/SecondTrailerIdentifier"/></TrailerStateSignID2>
						<VINID><xsl:value-of select="//ShippingInformation/BorderTransport[1]/VINID"/></VINID>
						<TransportMeansNationalityCode><xsl:value-of select="//ShippingInformation/BorderTransport[1]/TransportMeansNationalityCode"/></TransportMeansNationalityCode>
						<TransportModeCode><xsl:value-of select="//ShippingInformation/BorderTransport[1]/TransportModeCode"/></TransportModeCode>
						<TakingCargoPlace_CountryCode><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryACode"/></TakingCargoPlace_CountryCode>
						<TakingCargoPlace_CountryName><xsl:value-of select="//ShippingInformation/DispatchCountry/CountryName"/></TakingCargoPlace_CountryName>
						<ObCena><xsl:value-of select="sum(Goods/InvoicedCost)"/></ObCena>
					</CMR_ITEM>
				</CMR>			
				<xsl:if test="count(//GoodsPackaging/PackingInformation[string-length(PackingCode)>0])>0">
					<xsl:call-template name="PackList">
						<xsl:with-param name="PosSh" select="$PosShip"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each> 
			<xsl:call-template name="Apendix"/>
		</Package>
	</xsl:template>
</xsl:stylesheet>
