<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="../../COMMON/FunctionForXsl.xsl"/>
	<xsl:import href="../../COMMON/FunctionForArmtyXsl.xsl"/>
	<xsl:template name="SumStr">
		<xsl:param name="SumValue"/>
		<xsl:variable name="SumVal1" select="format-number(substring-before(format-number($SumValue,'#.000'),'.'),'#')"/>
		<xsl:variable name="SumVal2">
			<xsl:call-template name='RecurseSumWords'>
				<xsl:with-param name='Value' select='$SumVal1'/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="SumVal3" select="format-number(format-number($SumValue,'#.000')-$SumVal1,'0.000')"/>
		<xsl:choose>
			<xsl:when test="$SumVal3!=0">
				<xsl:value-of select="concat($SumVal2,'КГ ,', substring-after(string($SumVal3),'.'),' ГР')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat($SumVal2,'КГ ')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	<xsl:output method="xml"/>
	<xsl:key use="./ContainerNumbers" name="CountCntN" match="//Wagon"/>
	<xsl:key use="concat(../SMGSNumber,./ContainerNumbers)" name="CntN" match="//Goods"/>
	<xsl:template match="//Goods">
		<xsl:for-each select="ContainerNumbers">
		<CONTAINER_ITEM>
			<DOC_ID>0000</DOC_ID>
			<ContainerID><xsl:value-of select="."/></ContainerID>
		</CONTAINER_ITEM>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="/">
		<xsl:apply-templates select="//PI_RwArrive"/>
	</xsl:template>
	
	<xsl:template match="PI_RwArrive">
		<Package>
			<xsl:for-each select="GoodsShipment">
				<INVOICE ctmtd:CfgName="invoice.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
					<INVOICE_ITEM>
						<DOC_ID>0</DOC_ID>
						<SMGS><xsl:value-of select="SMGSNumber"/></SMGS>
						<CurrencyCode><xsl:value-of select="Goods[1]/CurrencyCode"/></CurrencyCode>
						<xsl:if test="format-number(sum(Goods/GrossWeightQuantity),'#.000')>0">
							<GrossWeightQuantity><xsl:value-of select="format-number(sum(Goods/GrossWeightQuantity),'#.000')"/></GrossWeightQuantity>
						</xsl:if>
						<xsl:if test="format-number(sum(Goods/NetWeightQuantity),'#.000')>0">
							<NetWeightQuantity><xsl:value-of select="format-number(sum(Goods/NetWeightQuantity),'#.000')"/></NetWeightQuantity>
						</xsl:if>
						<xsl:if test="format-number(sum(//Goods/InvoicedCost),'#.00')>0">
							<GCost><xsl:value-of select="format-number(sum(//Goods/InvoicedCost),'#.00')"/></GCost>
							<TotalCost><xsl:value-of select="format-number(sum(//Goods/InvoicedCost),'#.00')"/></TotalCost>
						</xsl:if>	
						<xsl:call-template name="Firm">
							<xsl:with-param name="ResNodeName" select="'Consignor'"/>
							<xsl:with-param name="LoadNodeName" select="Consignor"/>
							<xsl:with-param name="ShName" select="1"/>
						</xsl:call-template>
						<xsl:call-template name="Firm">
							<xsl:with-param name="ResNodeName" select="'Consignee'"/>
							<xsl:with-param name="LoadNodeName" select="Consignee"/>
							<xsl:with-param name="ShName" select="1"/>
						</xsl:call-template>

						<INVOICEGoods >
							<xsl:for-each select="Goods">						
								<INVOICEGOODS_ITEM>
									<DOC_ID>0</DOC_ID>
									<GoodsCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsCode>
									<GoodsDescription>
										<xsl:for-each select="GoodsDescription">
											<xsl:value-of select="."/>
										</xsl:for-each> 
									</GoodsDescription>
									<GoodsQuantity><xsl:value-of select="GoodsMeasureQuantity/GoodsQuantity"/></GoodsQuantity>
									<MeasureUnitQualifierName><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierName"/></MeasureUnitQualifierName>
									<MeasureUnitQualifierCode><xsl:value-of select="GoodsMeasureQuantity/MeasureUnitQualifierCode"/></MeasureUnitQualifierCode>
									<PlacesQuantity><xsl:value-of select="GoodsPackaging/PakageQuantity"/></PlacesQuantity>
									<PlacesDescription><xsl:value-of select="GoodsPackaging/CargoDescription"/></PlacesDescription>
									<PlacesCode><xsl:value-of select="GoodsPackaging/CargoCode"/></PlacesCode>
									<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"/></GrossWeightQuantity>
									<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
									<TotalCost><xsl:value-of select="InvoicedCost"/></TotalCost>
									<OriginCountryCode><xsl:value-of select="OriginCountryCode"/></OriginCountryCode> 
									<CarriageId>
										<xsl:if test="count(../WagonNumbers)=1">
											<xsl:value-of select="../WagonNumbers"/>
										</xsl:if>
									</CarriageId>
								</INVOICEGOODS_ITEM>
							</xsl:for-each>	
						</INVOICEGoods>
						<Carriage>
							<xsl:choose>
								<xsl:when test="count(WagonNumbers)>0">
									<xsl:for-each select="WagonNumbers">
										<CARRIAGE_ITEM>
											<DOC_ID>0</DOC_ID>
											<CarriageId><xsl:value-of select="."/></CarriageId>
										</CARRIAGE_ITEM>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="count(//Train/Wagon)=1 and count(Goods)=1">
									<CARRIAGE_ITEM>
										<DOC_ID>0</DOC_ID>
										<CarriageId><xsl:value-of select="//Train/Wagon/WagonNumber"/></CarriageId>
									</CARRIAGE_ITEM>
								</xsl:when>
							</xsl:choose>
						</Carriage>
						<Container>
							<xsl:apply-templates select="Goods[generate-id(.)=generate-id(key('CntN',concat(../SMGSNumber,./ContainerNumbers)))]"/>
						</Container>
						<DeadLine><xsl:value-of select="DateExpectedArrival"/></DeadLine>
						<DeadLineTime><xsl:value-of select="substring(TimeExpectedArrival,1,5)"/></DeadLineTime>
						<DispatchCountryCode><xsl:value-of select="DispatchCountry/CountryACode"/></DispatchCountryCode>
						<DispatchCountryName><xsl:value-of select="DispatchCountry/CountryName"/></DispatchCountryName>
						<DestinationCountryCode><xsl:value-of select="DestinationCountry/CountryACode"/></DestinationCountryCode>
						<DestinationCountryName><xsl:value-of select="DestinationCountry/CountryName"/></DestinationCountryName>
						<RegNum><xsl:value-of select="position()"/></RegNum>
					</INVOICE_ITEM>
				</INVOICE>
				<RWB xmlns:ctmtd="http://rail.ctm.ru/TD/Document" ctmtd:CfgName="RWB.CFG.XML">
					<RWB_ITEM>
						<DOC_ID>0</DOC_ID>
						<TrainNumber><xsl:value-of select="../Train/TrainNumber"/></TrainNumber>
						<TrainIndex><xsl:value-of select="../Train/TrainIndex"/></TrainIndex>
						<PPVNumber><xsl:value-of select="../Train/PPVNumber"/></PPVNumber>
						<ArrivalDate><xsl:value-of select="../Train/ArrivalDate"/></ArrivalDate>
						<RegNum><xsl:value-of select="SMGSNumber"/></RegNum>
						<xsl:if test="sum(Goods/GoodsMeasureQuantity/GoodsQuantity)>0">
							<PlacesQuantity><xsl:value-of select="sum(Goods/GoodsMeasureQuantity/GoodsQuantity)"/></PlacesQuantity>
							<PlacesQuantityStr>
								<xsl:call-template name='RecurseSumWords'>
									<xsl:with-param name='Value' select='sum(Goods/GoodsMeasureQuantity/GoodsQuantity)'/>
								</xsl:call-template>
							</PlacesQuantityStr>
						</xsl:if>	
						<xsl:if test="sum(Goods/GrossWeightQuantity)>0">
							<GrossWeightQuantity><xsl:value-of select="sum(Goods/GrossWeightQuantity)"/></GrossWeightQuantity>
							<GrossWeightQuantityStr>
								<xsl:call-template name='SumStr'>
									<xsl:with-param name='SumValue' select="format-number(sum(Goods/GrossWeightQuantity),'#.000')"/>
								</xsl:call-template>
							</GrossWeightQuantityStr>
						</xsl:if>
						<xsl:call-template name="Firm">
							<xsl:with-param name="ResNodeName" select="'Consignor'"/>
							<xsl:with-param name="LoadNodeName" select="Consignor"/>
							<xsl:with-param name="ShName" select="1"/>
						</xsl:call-template>
						<xsl:call-template name="Firm">
							<xsl:with-param name="ResNodeName" select="'Consignee'"/>
							<xsl:with-param name="LoadNodeName" select="Consignee"/>
							<xsl:with-param name="ShName" select="1"/>
						</xsl:call-template>

						<xsl:variable name="DepS" select="DepartureStation"/>
						<DepartureStationCode><xsl:value-of select="DepartureStation"/></DepartureStationCode>
						<DepartureStationName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=$DepS]/NAME"/></DepartureStationName>
						<DepStationCode><xsl:value-of select="DepartureStation"/></DepStationCode>
						<DepStationName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=$DepS]/NAME"/></DepStationName>
						<DepartureCustomCode><xsl:value-of select="BorderCustoms/Code"/></DepartureCustomCode>
						<xsl:variable name="DesT" select="DestinationStation"/>
						<DestinationStationCode><xsl:value-of select="DestinationStation"/></DestinationStationCode>
						<DestinationStationName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=$DesT]/NAME"/></DestinationStationName>
						
						<DestStationCode><xsl:value-of select="DestinationStation"/></DestStationCode>
						<DestStationName><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=$DesT]/NAME"/></DestStationName>
						
						<RWBGoods>
							<xsl:for-each select="Goods">
								<RWBGOODS_ITEM>
									<DOC_ID>0</DOC_ID>
									<GoodsDescription><xsl:value-of select="GoodsDescription"/></GoodsDescription>
									<PlacesDescription><xsl:value-of select="concat(GoodsPackaging/CargoCode,' ',GoodsPackaging/CargoDescription)"/></PlacesDescription>
									<GoodsNumeric><xsl:value-of select="GoodsNumeric"/></GoodsNumeric>
									<GoodsNomenclatureCode><xsl:value-of select="GoodsTNVEDCode"/></GoodsNomenclatureCode>
									<ContainerIndicator><xsl:value-of select="../ContainerIndicator"/></ContainerIndicator>
									<PlaceQuantity><xsl:value-of select="GoodsPackaging/PakageQuantity"/></PlaceQuantity>
									<GrossWeightQuantity><xsl:value-of select="GrossWeightQuantity"></xsl:value-of></GrossWeightQuantity>
								</RWBGOODS_ITEM>
							</xsl:for-each>
						</RWBGoods>
						<ContainerID>
							<xsl:choose>
								<xsl:when  test="string-length(Goods[1]/ContainerNumbers[1])>0">
									<xsl:value-of select="Goods[1]/ContainerNumbers[1]"/>
								</xsl:when>
								<xsl:when  test="count(//Train/Wagon[string-length(ContainerNumbers)>0])>0">
									<xsl:for-each select="//Train/Wagon[string-length(ContainerNumbers)>0][1]">
										<xsl:value-of select="ContainerNumbers"/>
									</xsl:for-each>
								</xsl:when>
							</xsl:choose>
						</ContainerID>
					  <RWBConsignorDocument nodetype="table">
						  <RWBCONSIGNORDOCUMENT_ITEM>
							<DOC_ID>0</DOC_ID>
							<DocumentName>Invoice</DocumentName>
							<DocumentNumber><xsl:value-of select="position()"/></DocumentNumber>
							<ModeCode>04021</ModeCode>
						  </RWBCONSIGNORDOCUMENT_ITEM>
					  </RWBConsignorDocument>
						<xsl:choose>
							<xsl:when test="count(WagonNumbers)>5">
								<RWBCarriage>
									<RWBCARRIAGE_ITEM>
										<DOC_ID>0</DOC_ID>
										<CarriageId>см.Вагонную ведомость</CarriageId>
									</RWBCARRIAGE_ITEM>
								</RWBCarriage>	
								<SMGS_VAGONS>
									<xsl:for-each select="WagonNumbers">
										<xsl:variable name="Wag" select="."/>
										<SMGS_VAGONS_ITEM>
											<DOC_ID>0</DOC_ID>
											<RailwayBill><xsl:value-of select="$Wag"/></RailwayBill>
											<xsl:for-each select="//Train/Wagon[WagonNumber=$Wag]">
												<xsl:variable name="CodCr" select="CountryRegistrationCode"/>
												<WOWNER><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CodCr]/RailCode"/></WOWNER>
												<GoodsWeight><xsl:value-of select="GoodsWeightQuantity"/></GoodsWeight>
											</xsl:for-each>
										</SMGS_VAGONS_ITEM>
									</xsl:for-each>	
								</SMGS_VAGONS>
							</xsl:when>
							<xsl:otherwise>
								<RWBCarriage>
									<xsl:choose>
										<xsl:when test="count(WagonNumbers)>0">
											<xsl:for-each select="WagonNumbers">
												<xsl:variable name="Wag" select="."/>
												<RWBCARRIAGE_ITEM>
													<DOC_ID>0</DOC_ID>
													<CarriageId><xsl:value-of select="$Wag"/></CarriageId>
													<xsl:for-each select="//Train/Wagon[WagonNumber=$Wag]">
														<xsl:variable name="CodCr" select="CountryRegistrationCode"/>
														<CarriageLand><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CodCr]/RailCode"/></CarriageLand>
														<GoodsWeight><xsl:value-of select="GoodsWeightQuantity"/></GoodsWeight>
													</xsl:for-each>	
												</RWBCARRIAGE_ITEM>
											</xsl:for-each>
										</xsl:when>
										<xsl:when test="count(../Wagon)=1 and count(Goods)=1">
											<RWBCARRIAGE_ITEM>
												<DOC_ID>0</DOC_ID>
												<xsl:variable name="CodCr" select="CountryRegistrationCode"/>
												<CarriageLand><xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$CodCr]/RailCode"/></CarriageLand>
												<CarriageId><xsl:value-of select="../Wagon/WagonNumber"/></CarriageId>
											</RWBCARRIAGE_ITEM>
										</xsl:when>
									</xsl:choose>												
								</RWBCarriage>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="count(//Wagon[generate-id(.)=generate-id(key('CountCntN',./ContainerNumbers))])>1">
							<CIM-SMGS_STATEMENT_CONTAINERS>
								<xsl:for-each select="WagonNumbers">
									<xsl:variable name="Wag" select="."/>
									<xsl:for-each select="//Train/Wagon[WagonNumber=$Wag]/ContainerNumbers">
									<CIM-SMGS_STATEMENT_CONTAINERS_ITEM>												
										<DOC_ID>0</DOC_ID>
										<N_VAGON><xsl:value-of select="$Wag"/></N_VAGON>
										<UTIN><xsl:value-of select="."/></UTIN>
									</CIM-SMGS_STATEMENT_CONTAINERS_ITEM>
									</xsl:for-each>			
								</xsl:for-each>	
							</CIM-SMGS_STATEMENT_CONTAINERS>
						</xsl:if>
					</RWB_ITEM>
				</RWB>	
			</xsl:for-each>
		</Package>
	</xsl:template>
</xsl:stylesheet>
