<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document" exclude-result-prefixes="ctmtd">
	<xsl:import href="../../COMMON/Package.xsl"/>
	<xsl:import href="../../COMMON/FunctionForArmtyXsl.xsl"/>
	<xsl:import href="EDEXPRESS-incomings-map.xsl"/>
	<xsl:template match="/">
		<xsl:for-each select="Package">
			<contains-documents-to-extract-to-package>
				<xsl:call-template name="ReqInventoryDoc"/>
				<xsl:call-template name="incomings-to-html">
					<xsl:with-param name="incomings-map" select="$EDEXPRESS-incomings-map"/>
				</xsl:call-template>
			</contains-documents-to-extract-to-package>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ReqInventoryDoc">
		<xsl:choose>
			<xsl:when test="count(key('PackageDocument', 'ReqInventoryDoc.html.cfg.xml'))">
				<!--уже есть, ничего не делаем-->
			</xsl:when>
			<xsl:when test="count(key('PackageDocument', 'ED.11003.cfg.xml'))">
				<!--ничего здесь не делаем, уже сделается через incomings-to-html с фильтром одного документа, для которого этот пакет-->
			</xsl:when>
			<xsl:otherwise>
				<!--только за-ради показа человеку дублируем свойства пакета в имитации таможенного документа. Настоящий экземпляр документа есть у Монитора ЭД, но нам не передан. Имитация даёт возможность использовать готовую форму просмотра таможенного документа.-->
				<!--xmlns таможенные не требуются для показа в html (там всё равно удаляются все xmlns)-->
				<ReqInventoryDoc ctmtd:CfgName="ReqInventoryDoc.html.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document" DocumentModeID="1006006E">
					<DocumentID>
						<xsl:value-of select="key('prop', 'ReqId')"/>
					</DocumentID>
					<DocSign>0</DocSign>
					<RequestedDoc>
						<PrDocumentName>
							<xsl:value-of select="key('prop', 'ReqDocName')"/>
						</PrDocumentName>
						<PrDocumentNumber>
							<xsl:value-of select="key('prop', 'ReqDocNum')"/>
						</PrDocumentNumber>
						<PrDocumentDate>
							<xsl:call-template name="TranslateDate">
								<xsl:with-param name="Dat" select="key('prop', 'ReqDocDate')"/>
							</xsl:call-template>
						</PrDocumentDate>
						<RequestPositionID>
							<xsl:value-of select="key('prop', 'ReqPosId')"/>
						</RequestPositionID>
						<DocCode>
							<xsl:value-of select="key('prop', 'ReqDocCode')"/>
						</DocCode>
						<InventLineID>
							<xsl:value-of select="key('prop', 'ReqInvLineId')"/>
						</InventLineID>
					</RequestedDoc>
				</ReqInventoryDoc>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*[ 'RequestedDoc' = local-name() ]">
		<xsl:variable name="RequestPositionID-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'RequestPositionID' = local-name() ]"/>
				<xsl:with-param name="string2" select="key('prop', 'ReqPosId')"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="DocCode-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'DocCode' = local-name() ]"/>
				<xsl:with-param name="string2" select="key('prop', 'ReqDocCode')"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PrDocumentName-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'PrDocumentName' = local-name() ]"/>
				<xsl:with-param name="string2" select="key('prop', 'ReqDocName')"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PrDocumentNumber-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'PrDocumentNumber' = local-name() ]"/>
				<xsl:with-param name="string2" select="key('prop', 'ReqDocNum')"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PrDocumentDate-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'PrDocumentDate' = local-name() ]"/>
				<xsl:with-param name="string2">
					<xsl:call-template name="TranslateDate">
						<xsl:with-param name="Dat" select="key('prop', 'ReqDocDate')"/>
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="InventLineID-match">
			<xsl:call-template name="match-if-equals-or-empty-both">
				<xsl:with-param name="string1" select="*[ 'InventLineID' = local-name() ]"/>
				<xsl:with-param name="string2" select="key('prop', 'ReqInvLineId')"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="string($RequestPositionID-match) and string($DocCode-match) and string($PrDocumentName-match) and string($PrDocumentNumber-match) and string($PrDocumentDate-match) and string($InventLineID-match)">
			<xsl:copy>
				<xsl:call-template name="copy-content"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<xsl:template name="match-if-equals-or-empty-both">
		<xsl:param name="string1"/>
		<xsl:param name="string2"/>
		<xsl:if test="( not(string($string1)) and not(string($string2)) ) or ($string1 = $string2)">
			<xsl:value-of select="'match'"/>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
