<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml"/>
	<xsl:template match="*|/">
		<xsl:apply-templates select="/Package"/>
	</xsl:template>
	<xsl:template name="ValFromNode">
		<xsl:param  name="NodeName"/>
		<xsl:element name="{$NodeName}">
			<xsl:for-each select="*[name()=$NodeName]">
				<xsl:value-of select="."/>
				<xsl:text> </xsl:text>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="Package">
		<OEZ_EXPORTPASS ctmtd:CfgName="OEZ_ExportPass.cfg.xml" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:for-each select="//OEZ_ExportPass">
				<OEZ_EXPORTPASS_ITEM>
					<BeginDate><xsl:value-of select="BeginDate"/></BeginDate>
					<LimitDate><xsl:value-of select="LimitDate"/></LimitDate>
					<xsl:variable name="RegDate">
						<xsl:value-of select="substring(RegistrationNumber/RegistrationDate,9,2)"/>
						<xsl:value-of select="substring(RegistrationNumber/RegistrationDate,6,2)"/>
						<xsl:value-of select="substring(RegistrationNumber/RegistrationDate,3,2)"/>
					</xsl:variable>
					<RegistrationNumber><xsl:value-of select="concat(RegistrationNumber/CustomsCode,'/',$RegDate,'/',RegistrationNumber/Number)"/></RegistrationNumber>
					<xsl:for-each select="Consignor">
						<xsl:variable name="ConsignorInfo">
							<xsl:value-of select="OrganizationName"/>
							<xsl:if test="string-length(Address/PostalCode)>0">
								<xsl:text> </xsl:text>
								<xsl:value-of select="Address/PostalCode"/>
								<xsl:text>, </xsl:text>
							</xsl:if> 
							<xsl:if test="string-length(Address/CounryName)>0">
								<xsl:value-of select="Address/CounryName"/>
								<xsl:text>, </xsl:text>
							</xsl:if> 
							<xsl:if test="string-length(Address/Region)>0">
								<xsl:value-of select="Address/Region"/>
								<xsl:text>, </xsl:text>
							</xsl:if> 
							<xsl:if test="string-length(Address/City)>0">
								<xsl:value-of select="Address/City"/>
								<xsl:text>, </xsl:text>
							</xsl:if>
							<xsl:if test="string-length(Address/StreetHouse)>0">
								<xsl:value-of select="Address/StreetHouse"/>
								<xsl:text>, </xsl:text>
							</xsl:if> 
							<xsl:if test="string-length(RFOrganizationFeatures/OGRN)>0">
								<xsl:value-of select="RFOrganizationFeatures/OGRN"/>
								<xsl:text> </xsl:text>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="string-length(RFOrganizationFeatures/INN)>0">
									<xsl:value-of select="RFOrganizationFeatures/INN"/>
								</xsl:when>
								<xsl:when test="string-length(RKOrganizationFeatures/IIN)>0">
									<xsl:value-of select="RKOrganizationFeatures/IIN"/>
								</xsl:when>
								<xsl:when test="string-length(RBOrganizationFeatures/UNP)>0">
									<xsl:value-of select="RBOrganizationFeatures/UNP"/>
								</xsl:when>
							</xsl:choose>													 				
							<xsl:text> </xsl:text>
							<xsl:if test="string-length(RFOrganizationFeatures/KPP)>0">
								<xsl:value-of select="RFOrganizationFeatures/KPP"/>
								<xsl:text> </xsl:text>
							</xsl:if>										
						</xsl:variable>	
						<Consignor_Info><xsl:value-of select="normalize-space($ConsignorInfo)"/></Consignor_Info>
						<Consignor_Name><xsl:value-of select="OrganizationName"/></Consignor_Name>
						<Consignor_ShortName><xsl:value-of select="ShortName"/></Consignor_ShortName>
						<Consignor_OGRN><xsl:value-of select="RFOrganizationFeatures/OGRN"/></Consignor_OGRN>
						<xsl:choose>
							<xsl:when test="string-length(RFOrganizationFeatures/INN)>0">
								<Consignor_INN><xsl:value-of select="RFOrganizationFeatures/INN"/></Consignor_INN>
							</xsl:when>
							<xsl:when test="string-length(RKOrganizationFeatures/IIN)>0">
								<Consignor_INN><xsl:value-of select="RKOrganizationFeatures/IIN"/></Consignor_INN>
							</xsl:when>
							<xsl:when test="string-length(RBOrganizationFeatures/UNP)>0">
								<Consignor_INN><xsl:value-of select="RBOrganizationFeatures/UNP"/></Consignor_INN>
							</xsl:when>
						</xsl:choose>
						<Consignor_KPP><xsl:value-of select="RFOrganizationFeatures/KPP"/></Consignor_KPP>
						<Consignor_SertificateNumberOEZ><xsl:value-of select="SertificateNumberOEZ"/></Consignor_SertificateNumberOEZ>
						<xsl:for-each select="Address">
							<Consignor_PostalCode><xsl:value-of select="PostalCode"/></Consignor_PostalCode>
							<Consignor_CountryCode><xsl:value-of select="CountryCode"/></Consignor_CountryCode>
							<Consignor_CountryName><xsl:value-of select="CounryName"/></Consignor_CountryName>
							<Consignor_Region><xsl:value-of select="Region"/></Consignor_Region>
							<Consignor_City><xsl:value-of select="City"/></Consignor_City>
							<Consignor_StreetHouse><xsl:value-of select="StreetHouse"/></Consignor_StreetHouse>
						</xsl:for-each>
					</xsl:for-each>
					<xsl:for-each select="TransportMeans">
						<TransportKind><xsl:value-of select="TransportKind"/></TransportKind>
						<TransportNumber>
							<xsl:for-each select="ActiveTransportIdentifier">
								<TRANSPORTNUMBER_ITEM>
									<DOC_ID>0</DOC_ID>
									<TransportRegNumber><xsl:value-of select="."/></TransportRegNumber>
								</TRANSPORTNUMBER_ITEM>
							</xsl:for-each>	
							<xsl:for-each select="TransportRegNumber">
								<TRANSPORTNUMBER_ITEM>
									<DOC_ID>0</DOC_ID>
									<TransportRegNumber><xsl:value-of select="."/></TransportRegNumber>
								</TRANSPORTNUMBER_ITEM>
							</xsl:for-each>	
						</TransportNumber>
						<TransportMark><xsl:value-of select="TransportMark"/></TransportMark>
					</xsl:for-each>	
					<xsl:for-each select="CustomsPerson">
						<CustomsPersonFIO><xsl:value-of select="PersonName"/></CustomsPersonFIO>
						<CustomsPersonLNP><xsl:value-of select="LNP"/></CustomsPersonLNP>
					</xsl:for-each>	
					<OEZ_EXPORTPASSGoods>
						<xsl:for-each select="GoodsList">
							<OEZ_EXPORTPASSGOODS_ITEM>
								<DOC_ID>0</DOC_ID>
								<xsl:call-template name="ValFromNode">
									<xsl:with-param name="NodeName" select="'GoodsDescription'"/> 
								</xsl:call-template>
								<WeighQuantity><xsl:value-of select="WeighQuantity"/></WeighQuantity>
								<PackagesQuantity><xsl:value-of select="PackagesQuantity"/></PackagesQuantity>
								<PackagingKind><xsl:value-of select="PackagingKind"/></PackagingKind>
								<PackingCode><xsl:value-of select="PackingCode"/></PackingCode>
								<GoodsQuantity><xsl:value-of select="SupplementaryQuantity/GoodsQuantity"/></GoodsQuantity>
								<MeasureUnitQualifierName><xsl:value-of select="SupplementaryQuantity/MeasureUnitQualifierName"/></MeasureUnitQualifierName>
								<MeasureUnitQualifierCode><xsl:value-of select="SupplementaryQuantity/MeasureUnitQualifierCode"/></MeasureUnitQualifierCode>
								<GoodsStatusEx>
									<xsl:for-each select="GoodsStatus">
										<GOODSSTATUSEX_ITEM>
											<DOC_ID>0</DOC_ID>
											<StatusSymbolicValue><xsl:value-of select="StatusSymbolicValue"/></StatusSymbolicValue>
											<CustomsModeCode><xsl:value-of select="CustomsModeCode"/></CustomsModeCode>
											<GoodsNumeric><xsl:value-of select="GoodsNumeric"/></GoodsNumeric>
											<NetWeightQuantity><xsl:value-of select="NetWeightQuantity"/></NetWeightQuantity>
											<xsl:variable name="GDate">
												<xsl:value-of select="substring(GTDID/RegistrationDate,9,2)"/>
												<xsl:value-of select="substring(GTDID/RegistrationDate,6,2)"/>
												<xsl:value-of select="substring(GTDID/RegistrationDate,3,2)"/>
											</xsl:variable>
											<GTD><xsl:value-of select="concat(GTDID/CustomsCode,'/',$GDate,'/',GTDID/GTDNumber)"/></GTD>
											<GoodsQuantityEx><xsl:value-of select="SupplementaryQuantity/GoodsQuantity"/></GoodsQuantityEx>
											<MeasureUnitQualifierNameEx><xsl:value-of select="SupplementaryQuantity/MeasureUnitQualifierName"/></MeasureUnitQualifierNameEx>
											<MeasureUnitQualifierCodeEx><xsl:value-of select="SupplementaryQuantity/MeasureUnitQualifierCode"/></MeasureUnitQualifierCodeEx>
										</GOODSSTATUSEX_ITEM>
									</xsl:for-each>	
								</GoodsStatusEx>	
							</OEZ_EXPORTPASSGOODS_ITEM>
						</xsl:for-each>
					</OEZ_EXPORTPASSGoods>
					<DocumentExp>
						<xsl:for-each select="DocumentExp">
							<DOCUMENTEXP_ITEM>
								<DOC_ID>0</DOC_ID>
								<DocName><xsl:value-of select="PrDocumentName"/></DocName>
								<DocNumber><xsl:value-of select="PrDocumentNumber"/></DocNumber>
								<xsl:if test="string-length(PrDocumentDate)>0">
									<DocDate><xsl:value-of select="concat(PrDocumentDate,'T00:00:00+04:00')"/></DocDate>
								</xsl:if>
							</DOCUMENTEXP_ITEM>
						</xsl:for-each>
					</DocumentExp>	
				</OEZ_EXPORTPASS_ITEM>
			</xsl:for-each>
		</OEZ_EXPORTPASS>
	</xsl:template>
</xsl:stylesheet>
