<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml"/>
	<xsl:template match="*|/">
		<xsl:apply-templates select="/Package"/>
	</xsl:template>
	<xsl:template name="ValFromNode">
		<xsl:param  name="NodeName"/>
		<xsl:element name="{$NodeName}">
			<xsl:for-each select="*[name()=$NodeName]">
				<xsl:value-of select="."/>
				<xsl:text> </xsl:text>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template match="Package">
		<OEZ_GOODSIDENTIFY>
			<xsl:for-each select="//OEZ_GoodsIdentify">
				<OEZ_GOODSIDENTIFY_ITEM>
					<DateDocument><xsl:value-of select="DateDocument"/></DateDocument>
					<xsl:variable name="RegDate">
						<xsl:value-of select="substring(RegistrationNumberImp/RegistrationDate,9,2)"/>
						<xsl:value-of select="substring(RegistrationNumberImp/RegistrationDate,6,2)"/>
						<xsl:value-of select="substring(RegistrationNumberImp/RegistrationDate,3,2)"/>
					</xsl:variable>
					<RegistrationNumber><xsl:value-of select="concat(RegistrationNumberImp/CustomsCode,'/',$RegDate,'/',RegistrationNumberImp/Number)"/></RegistrationNumber>
					<xsl:call-template name="ValFromNode">
						<xsl:with-param name="NodeName" select="'Reason'"/> 
					</xsl:call-template>
					<xsl:call-template name="ValFromNode">
						<xsl:with-param name="NodeName" select="'PlaceIdentify'"/> 
					</xsl:call-template>
					<xsl:call-template name="ValFromNode">
						<xsl:with-param name="NodeName" select="'Activity'"/> 
					</xsl:call-template>					
					<xsl:call-template name="ValFromNode">
						<xsl:with-param name="NodeName" select="'PresentInfo'"/> 
					</xsl:call-template>
					<Code><xsl:value-of select="Customs/Code"/></Code>
					<OfficeName><xsl:value-of select="Customs/OfficeName"/></OfficeName>
					<xsl:for-each select="Consignee">
						<Consignee_Name><xsl:value-of select="OrganizationName"/></Consignee_Name>
						<Consignee_ShortName><xsl:value-of select="ShortName"/></Consignee_ShortName>
						<Consignee_OGRN><xsl:value-of select="RFOrganizationFeatures/OGRN"/></Consignee_OGRN>
						<xsl:choose>
							<xsl:when test="string-length(RFOrganizationFeatures/INN)>0">
								<Consignee_INN><xsl:value-of select="RFOrganizationFeatures/INN"/></Consignee_INN>
							</xsl:when>
							<xsl:when test="string-length(RKOrganizationFeatures/IIN)>0">
								<Consignee_INN><xsl:value-of select="RKOrganizationFeatures/IIN"/></Consignee_INN>
							</xsl:when>
							<xsl:when test="string-length(RBOrganizationFeatures/UNP)>0">
								<Consignee_INN><xsl:value-of select="RBOrganizationFeatures/UNP"/></Consignee_INN>
							</xsl:when>
						</xsl:choose>
						<Consignee_KPP><xsl:value-of select="RFOrganizationFeatures/KPP"/></Consignee_KPP>
						<Consignee_SertificateNumberOEZ><xsl:value-of select="SertificateNumberOEZ"/></Consignee_SertificateNumberOEZ>
						<xsl:for-each select="Address">
							<Consignee_PostalCode><xsl:value-of select="PostalCode"/></Consignee_PostalCode>
							<Consignee_CountryCode><xsl:value-of select="CountryCode"/></Consignee_CountryCode>
							<Consignee_CountryName><xsl:value-of select="CountryName"/></Consignee_CountryName>
							<Consignee_Region><xsl:value-of select="Region"/></Consignee_Region>
							<Consignee_City><xsl:value-of select="City"/></Consignee_City>
							<Consignee_StreetHouse><xsl:value-of select="StreetHouse"/></Consignee_StreetHouse>
						</xsl:for-each>
						<xsl:for-each select="IdentityCard">
							<Consignee_IdentityCardCode><xsl:value-of select="IdentityCardCode"/></Consignee_IdentityCardCode>
							<Consignee_IdentityCardName><xsl:value-of select="IdentityCardName"/></Consignee_IdentityCardName>
							<Consignee_IdentityCardSeries><xsl:value-of select="IdentityCardSeries"/></Consignee_IdentityCardSeries>
							<Consignee_IdentityCardNumder><xsl:value-of select="IdentityCardNumber"/></Consignee_IdentityCardNumder>
							<Consignee_IdentityCardDate><xsl:value-of select="IdentityCardDate"/></Consignee_IdentityCardDate>
							<Consignee_OrganizationName><xsl:value-of select="OrganizationName"/></Consignee_OrganizationName>
						</xsl:for-each>	
					</xsl:for-each>
					<xsl:for-each select="CustomsPerson">
						<CustomsPersonFIO><xsl:value-of select="PersonName"/></CustomsPersonFIO>
						<CustomsPersonLNP><xsl:value-of select="LNP"/></CustomsPersonLNP>
					</xsl:for-each>	
					<OEZ_GOODSIDENTIFYGoods>
						<xsl:for-each select="GoodsInfo">
							<OEZ_GOODSIDENTIFYGOODS_ITEM>
								<DOC_ID>0</DOC_ID>
								<xsl:call-template name="ValFromNode">
									<xsl:with-param name="NodeName" select="'GoodsDescription'"/> 
								</xsl:call-template>
								<Position><xsl:value-of select="Position"/></Position>
							</OEZ_GOODSIDENTIFYGOODS_ITEM>
						</xsl:for-each>	
					</OEZ_GOODSIDENTIFYGoods>
				</OEZ_GOODSIDENTIFY_ITEM>
			</xsl:for-each>
		</OEZ_GOODSIDENTIFY>
	</xsl:template>
</xsl:stylesheet>
